@@ -331,15 +331,13 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv,dirs,buildApi=="True",buildWorker="True"):
-
+def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
 
     # ensure maven installs all build tools
-    local("pwd")
-    local('mvn clean install -DskipTests')
+	local("pwd")
+	local('mvn clean install -DskipTests')
 
-
-    if buildApi in TRUTH_VALUES:
+	if buildApi:
 	    local('mkdir -p deploy/api/config')
 	    local('mkdir -p deploy/api/lib')
 	 
@@ -352,7 +350,7 @@ def build2(javaEnv,dirs,buildApi=="True",buildWorker="True"):
 	    local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
 
-	if buildWorker in TRUTH_VALUES:
+	if buildWorker:
 	    local('mkdir -p deploy/worker/config')
 	    local('mkdir -p deploy/worker/lib')
 
@@ -370,7 +368,6 @@ def build2(javaEnv,dirs,buildApi=="True",buildWorker="True"):
 
 
 
-
 # Obtain git_sha from Jenkins git plugin, make sure it's passed along with the code so that
 # uwsgi, djangorq, and and celery can make use of it (e.g. to pass to
 # Sentry for releases)
